@@ -1,4 +1,4 @@
-package Sim::OPT::Interlinear;
+#package Sim::OPT::Interlinear;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE LINE ABOVE SHOULD BE DELETED.
 
 # INTERLINEAR
@@ -22,13 +22,13 @@ use feature 'say';
 no strict;
 no warnings;
 
-use Sim::OPT;
-use Sim::OPT::Morph;
-use Sim::OPT::Sim;
-use Sim::OPT::Report;
-use Sim::OPT::Descend;
-use Sim::OPT::Takechance;
-use Sim::OPT::Parcoord3d;
+#use Sim::OPT;
+#use Sim::OPT::Morph;
+#use Sim::OPT::Sim;
+#use Sim::OPT::Report;
+#use Sim::OPT::Descend;
+#use Sim::OPT::Takechance;
+#use Sim::OPT::Parcoord3d;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE ABOVE "use Sim::OPT..." lines should be deleted.
 
 our @ISA = qw( Exporter );
@@ -1126,20 +1126,20 @@ sub wei
       }
 
 
-      #foreach my $el ( @weldarr )
-      #{
-      #  if ( ( $weldnears{$el->[0]}{all}->[2] eq "" ) or ( ( $weldnears{$el->[0]}{all}->[3] < 1 ) and ( $weldnears{$el->[0]}{all}->[2] != $el->[2] ) ) )
-      #  {
-      #    $weldnears{$el->[0]}{all} = $el;
-      #  }
-      #}
+      foreach my $el ( @weldarr )
+      {
+        if ( ( $weldnears{$el->[0]}{all}->[2] eq "" ) or ( ( $weldnears{$el->[0]}{all}->[3] < 1 ) and ( $weldnears{$el->[0]}{all}->[2] != $el->[2] ) ) )
+        {
+          $weldnears{$el->[0]}{all} = $el;
+        }
+      }
       #say $tee " \%weldnears: " . dump( \%weldnears );
 
       #say $tee "FIRST0 $first0,  LAST0 $last0 ";
       #say $tee " \@weldarr__: " . dump( \@weldarr__ ) ;
       #say $tee " \%factlevels: " . dump( \%factlevels ) ;
       #say $tee " \@weldarra: " . dump( \@weldarra ) ;
-      my ( $weldbank_ref, $weldnears_ref ) = fillbank( \@weldarr__, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels, $nfilter, \@weldarra, $first0, $last0, \%nears );
+      my ( $weldbank_ref, $weldnears_ref ) = fillbank( \@weldarr__, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels, $nfilter, \@weldarra, $first0, $last0, \%weldnears );
       %weldbank = %{ $weldbank_ref }; say $tee " \%weldbank: " . dump( \%weldbank ) ;
       %weldnears = %{ $weldnears_ref };
 
